# Parity Package

The `parity` package provides models and utilities based on the principles of put-call parity.

-   **Parity Model**: A utility to calculate the price of a complementary option (e.g., a put from a call) based on the parity relationship.
-   **Implied Rate Model**: A model to solve for the risk-free interest rate that is implied by the market prices of a put-call pair.